==> haskell-text-builder-0.6.7-167-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-builder
version:              0.6.7
visibility:           public
id:                   text-builder-0.6.7-JdBpEXlGiAG6pvhPmps6B3
key:                  text-builder-0.6.7-JdBpEXlGiAG6pvhPmps6B3
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder
synopsis:             An efficient strict text builder
category:             Text
abi:                  4095be45c37a14d7ad61d80804532f62
exposed:              True
exposed-modules:      Text.Builder
hidden-modules:       Text.Builder.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-builder-0.6.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-builder-0.6.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-builder-0.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder
hs-libraries:         HStext-builder-0.6.7-JdBpEXlGiAG6pvhPmps6B3
depends:
    base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
    text-builder-dev-0.3.3.2-97AsOrTN8iK2uqh6iaWRMD

haddock-interfaces:
    /usr/share/doc/haskell-text-builder/html/text-builder.haddock

haddock-html:         /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-builder-0.6.7-179-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-builder
version:              0.6.7
visibility:           public
id:                   text-builder-0.6.7-JGxcvblHeU716rdie71b8e
key:                  text-builder-0.6.7-JGxcvblHeU716rdie71b8e
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder
synopsis:             An efficient strict text builder
category:             Text
abi:                  0f2143cb41c33c3f9a52f890225e02c1
exposed:              True
exposed-modules:      Text.Builder
hidden-modules:       Text.Builder.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-builder-0.6.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-builder-0.6.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-builder-0.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder
hs-libraries:         HStext-builder-0.6.7-JGxcvblHeU716rdie71b8e
depends:
    base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
    text-builder-dev-0.3.3.2-9kWAaxdUAPEvMCXUIR398

haddock-interfaces:
    /usr/share/doc/haskell-text-builder/html/text-builder.haddock

haddock-html:         /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
